@@ -36,7 +36,6 @@
 //
 //===----------------------------------------------------------------------===//
 #include "LLVMToSPIRVDbgTran.h"
-#include "SPIRV.debug.h"
 #include "SPIRVWriter.h"
 
 #include "llvm/IR/DebugInfo.h"
@@ -53,13 +52,6 @@ void LLVMToSPIRVDbgTran::transDebugMetadata() {
   if (DIF.compile_unit_count() == 0)
     return;
 
-  if (isNonSemanticDebugInfo()) {
-    if (!BM->isAllowedToUseVersion(VersionNumber::SPIRV_1_6))
-      BM->addExtension(SPIRV::ExtensionID::SPV_KHR_non_semantic_info);
-    else
-      BM->setMinSPIRVVersion(VersionNumber::SPIRV_1_6);
-  }
-
   for (DICompileUnit *CU : DIF.compile_units()) {
     transDbgEntry(CU);
     for (DIImportedEntity *IE : CU->getImportedEntities())
@@ -291,6 +283,8 @@ SPIRVEntry *LLVMToSPIRVDbgTran::transDbgEntryImpl(const MDNode *MDN) {
   if (!MDN)
     return BM->addDebugInfo(SPIRVDebug::DebugInfoNone, getVoidTy(),
                             SPIRVWordVec());
+  if (isNonSemanticDebugInfo())
+    BM->addExtension(SPIRV::ExtensionID::SPV_KHR_non_semantic_info);
   if (const DINode *DIEntry = dyn_cast<DINode>(MDN)) {
     switch (DIEntry->getTag()) {
     // Types
@@ -365,6 +359,9 @@ SPIRVEntry *LLVMToSPIRVDbgTran::transDbgEntryImpl(const MDNode *MDN) {
         return transDbgLocalVariable(LV);
       if (const DIGlobalVariable *GV = dyn_cast<DIGlobalVariable>(DIEntry))
         return transDbgGlobalVariable(GV);
+      if (const DIDerivedType *MT = dyn_cast<DIDerivedType>(DIEntry))
+        if (M->getDwarfVersion() >= 5 && MT->isStaticMember())
+          return transDbgMemberType(MT);
       llvm_unreachable("Unxpected debug info type for variable");
     case dwarf::DW_TAG_formal_parameter:
       return transDbgLocalVariable(cast<DILocalVariable>(DIEntry));
@@ -810,9 +807,6 @@ SPIRVEntry *LLVMToSPIRVDbgTran::transDbgSubrangeType(const DISubrange *ST) {
       case CountIdx:
         IntNode = ST->getCount().get<ConstantInt *>();
         break;
-      case StrideIdx:
-        IntNode = ST->getStride().get<ConstantInt *>();
-        break;
       }
       Ops[Idx] = IntNode ? SPIRVWriter->transValue(IntNode, nullptr)->getId()
                          : getDebugInfoNoneId();
@@ -1025,8 +1019,6 @@ LLVMToSPIRVDbgTran::transDbgMemberTypeOpenCL(const DIDerivedType *MT) {
       Ops.push_back(Val->getId());
     }
   }
-  if (isNonSemanticDebugInfo())
-    transformToConstant(Ops, {LineIdx, ColumnIdx, FlagsIdx});
   return BM->addDebugInfo(SPIRVDebug::TypeMember, getVoidTy(), Ops);
 }
 
@@ -1060,32 +1052,20 @@ LLVMToSPIRVDbgTran::transDbgMemberTypeNonSemantic(const DIDerivedType *MT) {
 
 SPIRVEntry *LLVMToSPIRVDbgTran::transDbgInheritance(const DIDerivedType *DT) {
   using namespace SPIRVDebug::Operand::TypeInheritance;
-  unsigned ParentIdx, OffsetIdx, SizeIdx, FlagsIdx, OperandCount;
-  if (isNonSemanticDebugInfo()) {
-    ParentIdx = NonSemantic::ParentIdx;
-    OffsetIdx = NonSemantic::OffsetIdx;
-    SizeIdx = NonSemantic::SizeIdx;
-    FlagsIdx = NonSemantic::FlagsIdx;
-    OperandCount = NonSemantic::OperandCount;
-  } else {
-    ParentIdx = OpenCL::ParentIdx;
-    OffsetIdx = OpenCL::OffsetIdx;
-    SizeIdx = OpenCL::SizeIdx;
-    FlagsIdx = OpenCL::FlagsIdx;
-    OperandCount = OpenCL::OperandCount;
-  }
-  SPIRVWordVec Ops(OperandCount);
-  Ops[ParentIdx] = transDbgEntry(DT->getBaseType())->getId();
+  const SPIRVWord Offset = isNonSemanticDebugInfo() ? 1 : 0;
+  SPIRVWordVec Ops(OperandCount - Offset);
+  // There is no Child operand in NonSemantic debug spec
+  if (!isNonSemanticDebugInfo())
+    Ops[ChildIdx] = transDbgEntry(DT->getScope())->getId();
+  Ops[ParentIdx - Offset] = transDbgEntry(DT->getBaseType())->getId();
   ConstantInt *OffsetInBits = getUInt(M, DT->getOffsetInBits());
-  Ops[OffsetIdx] = SPIRVWriter->transValue(OffsetInBits, nullptr)->getId();
+  Ops[OffsetIdx - Offset] =
+      SPIRVWriter->transValue(OffsetInBits, nullptr)->getId();
   ConstantInt *Size = getUInt(M, DT->getSizeInBits());
-  Ops[SizeIdx] = SPIRVWriter->transValue(Size, nullptr)->getId();
-  Ops[FlagsIdx] = transDebugFlags(DT);
-  if (isNonSemanticDebugInfo()) {
-    transformToConstant(Ops, {FlagsIdx});
-  } else {
-    Ops[OpenCL::ChildIdx] = transDbgEntry(DT->getScope())->getId();
-  }
+  Ops[SizeIdx - Offset] = SPIRVWriter->transValue(Size, nullptr)->getId();
+  Ops[FlagsIdx - Offset] = transDebugFlags(DT);
+  if (isNonSemanticDebugInfo())
+    transformToConstant(Ops, {FlagsIdx - Offset});
   return BM->addDebugInfo(SPIRVDebug::TypeInheritance, getVoidTy(), Ops);
 }
 
@@ -1205,6 +1185,23 @@ LLVMToSPIRVDbgTran::transDbgGlobalVariable(const DIGlobalVariable *GV) {
   if (DIDerivedType *StaticMember = GV->getStaticDataMemberDeclaration())
     Ops.push_back(transDbgEntry(StaticMember)->getId());
 
+  // Check if Ops[VariableIdx] has no information
+  if (isNonSemanticDebugInfo() && Ops[VariableIdx] == getDebugInfoNoneId()) {
+    // Check if GV has an associated GVE with a non-empty DIExpression.
+    // The non-empty DIExpression gives the initial value of the GV.
+    for (const DIGlobalVariableExpression *GVE : DIF.global_variables()) {
+      if ( // GVE matches GV
+          GVE->getVariable() == GV &&
+          // DIExpression is non-empty
+          GVE->getExpression()->getNumElements()) {
+        // Repurpose VariableIdx operand to hold the initial value held in the
+        // GVE's DIExpression
+        Ops[VariableIdx] = transDbgExpression(GVE->getExpression())->getId();
+        break;
+      }
+    }
+  }
+
   if (isNonSemanticDebugInfo())
     transformToConstant(Ops, {LineIdx, ColumnIdx, FlagsIdx});
   return BM->addDebugInfo(SPIRVDebug::GlobalVariable, getVoidTy(), Ops);
@@ -1223,7 +1220,7 @@ SPIRVEntry *LLVMToSPIRVDbgTran::transDbgFunction(const DISubprogram *Func) {
   Ops[SourceIdx] = getSource(Func)->getId();
   Ops[LineIdx] = Func->getLine();
   Ops[ColumnIdx] = 0; // This version of DISubprogram has no column number
-  auto Scope = Func->getScope();
+  auto *Scope = Func->getScope();
   if (Scope && !isa<DIFile>(Scope)) {
     Ops[ParentIdx] = getScope(Scope)->getId();
   } else {
