@@ -48,13 +48,14 @@
 #include "llvm/IR/IRBuilder.h"
 #include "llvm/IR/Instruction.h"
 #include "llvm/IR/Instructions.h"
+#include "llvm/IR/PatternMatch.h"
 #include "llvm/Support/Debug.h"
 
 #include <algorithm>
-#include <regex>
 #include <set>
 
 using namespace llvm;
+using namespace PatternMatch;
 using namespace SPIRV;
 using namespace OCLUtil;
 
@@ -89,8 +90,8 @@ static Type *getBlockStructType(Value *Parameter) {
 /// for a demangled function name, or 0 if the function does not return an
 /// integer type (e.g. read_imagef).
 static unsigned getImageSignZeroExt(StringRef DemangledName) {
-  bool IsSigned = !DemangledName.endswith("ui") && DemangledName.back() == 'i';
-  bool IsUnsigned = DemangledName.endswith("ui");
+  bool IsSigned = !DemangledName.ends_with("ui") && DemangledName.back() == 'i';
+  bool IsUnsigned = DemangledName.ends_with("ui");
 
   if (IsSigned)
     return ImageOperandsMask::ImageOperandsSignExtendMask;
@@ -177,12 +178,8 @@ bool OCLToSPIRVBase::runOCLToSPIRV(Module &Module) {
 
   visit(*M);
 
-  for (auto &I : ValuesToDelete)
-    if (auto Inst = dyn_cast<Instruction>(I))
-      Inst->eraseFromParent();
-  for (auto &I : ValuesToDelete)
-    if (auto GV = dyn_cast<GlobalValue>(I))
-      GV->eraseFromParent();
+  for (Instruction *I : ValuesToDelete)
+    I->eraseFromParent();
 
   eraseUselessFunctions(M); // remove unused functions declarations
   LLVM_DEBUG(dbgs() << "After OCLToSPIRV:\n" << *M);
@@ -197,7 +194,7 @@ bool OCLToSPIRVBase::runOCLToSPIRV(Module &Module) {
 // there are functions fall into both categories.
 void OCLToSPIRVBase::visitCallInst(CallInst &CI) {
   LLVM_DEBUG(dbgs() << "[visistCallInst] " << CI << '\n');
-  auto F = CI.getCalledFunction();
+  auto *F = CI.getCalledFunction();
   if (!F)
     return;
 
@@ -232,7 +229,7 @@ void OCLToSPIRVBase::visitCallInst(CallInst &CI) {
         isComputeAtomicOCLBuiltin(DemangledName))
       return;
 
-    auto PCI = &CI;
+    auto *PCI = &CI;
     if (DemangledName == kOCLBuiltinName::AtomicInit) {
       visitCallAtomicInit(PCI);
       return;
@@ -330,8 +327,8 @@ void OCLToSPIRVBase::visitCallInst(CallInst &CI) {
   }
   if (DemangledName == kOCLBuiltinName::Dot ||
       DemangledName == kOCLBuiltinName::DotAccSat ||
-      DemangledName.startswith(kOCLBuiltinName::Dot4x8PackedPrefix) ||
-      DemangledName.startswith(kOCLBuiltinName::DotAccSat4x8PackedPrefix)) {
+      DemangledName.starts_with(kOCLBuiltinName::Dot4x8PackedPrefix) ||
+      DemangledName.starts_with(kOCLBuiltinName::DotAccSat4x8PackedPrefix)) {
     if (CI.getOperand(0)->getType()->isVectorTy()) {
       auto *VT = (VectorType *)(CI.getOperand(0)->getType());
       if (!isa<llvm::IntegerType>(VT->getElementType())) {
@@ -482,35 +479,24 @@ CallInst *OCLToSPIRVBase::visitCallAtomicCmpXchg(CallInst *CI) {
     auto Mutator = mutateCallInst(CI, kOCLBuiltinName::AtomicCmpXchgStrong);
     Value *Expected = Mutator.getArg(1);
     Type *MemTy = Mutator.getArg(2)->getType();
-    if (MemTy->isFloatTy() || MemTy->isDoubleTy()) {
-      MemTy =
-          MemTy->isFloatTy() ? Type::getInt32Ty(*Ctx) : Type::getInt64Ty(*Ctx);
-      Mutator.replaceArg(
-          0,
-          {Mutator.getArg(0),
-           TypedPointerType::get(
-               MemTy, Mutator.getArg(0)->getType()->getPointerAddressSpace())});
-      Mutator.mapArg(2, [=](IRBuilder<> &Builder, Value *V) {
-        return Builder.CreateBitCast(V, MemTy);
-      });
-    }
     assert(MemTy->isIntegerTy() &&
            "In SPIR-V 1.0 arguments of OpAtomicCompareExchange must be "
            "an integer type scalars");
     Mutator.mapArg(1, [=](IRBuilder<> &Builder, Value *V) {
       return Builder.CreateLoad(MemTy, V, "exp");
     });
-    Mutator.changeReturnType(MemTy, [&](IRBuilder<> &Builder, CallInst *NCI) {
-      NewCI = NCI;
-      Builder.CreateStore(NCI, Expected);
-      return Builder.CreateICmpEQ(NCI, NCI->getArgOperand(1));
-    });
+    Mutator.changeReturnType(
+        MemTy, [Expected, &NewCI](IRBuilder<> &Builder, CallInst *NCI) {
+          NewCI = NCI;
+          Builder.CreateStore(NCI, Expected);
+          return Builder.CreateICmpEQ(NCI, NCI->getArgOperand(1));
+        });
   }
   return NewCI;
 }
 
 void OCLToSPIRVBase::visitCallAtomicInit(CallInst *CI) {
-  auto ST = new StoreInst(CI->getArgOperand(1), CI->getArgOperand(0), CI);
+  auto *ST = new StoreInst(CI->getArgOperand(1), CI->getArgOperand(0), CI);
   ST->takeName(CI);
   CI->dropAllReferences();
   CI->eraseFromParent();
@@ -523,7 +509,7 @@ void OCLToSPIRVBase::visitCallAllAny(spv::Op OC, CallInst *CI) {
   assert(Args.size() == 1);
 
   auto *ArgTy = Args[0]->getType();
-  auto Zero = Constant::getNullValue(Args[0]->getType());
+  auto *Zero = Constant::getNullValue(Args[0]->getType());
 
   auto *Cmp = CmpInst::Create(CmpInst::ICmp, CmpInst::ICMP_SLT, Args[0], Zero,
                               "cast", CI);
@@ -568,9 +554,9 @@ void OCLToSPIRVBase::transMemoryBarrier(CallInst *CI,
 void OCLToSPIRVBase::visitCallAtomicLegacy(CallInst *CI, StringRef MangledName,
                                            StringRef DemangledName) {
   StringRef Stem = DemangledName;
-  if (Stem.startswith("atom_"))
+  if (Stem.starts_with("atom_"))
     Stem = Stem.drop_front(strlen("atom_"));
-  else if (Stem.startswith("atomic_"))
+  else if (Stem.starts_with("atomic_"))
     Stem = Stem.drop_front(strlen("atomic_"));
   else
     return;
@@ -600,7 +586,7 @@ void OCLToSPIRVBase::visitCallAtomicLegacy(CallInst *CI, StringRef MangledName,
   Info.UniqName = "atomic_" + Prefix + Sign + Stem.str() + Postfix;
   std::vector<int> PostOps;
   PostOps.push_back(OCLLegacyAtomicMemOrder);
-  if (Stem.startswith("compare_exchange"))
+  if (Stem.starts_with("compare_exchange"))
     PostOps.push_back(OCLLegacyAtomicMemOrder);
   PostOps.push_back(OCLLegacyAtomicMemScope);
 
@@ -615,24 +601,24 @@ void OCLToSPIRVBase::visitCallAtomicLegacy(CallInst *CI, StringRef MangledName,
 void OCLToSPIRVBase::visitCallAtomicCpp11(CallInst *CI, StringRef MangledName,
                                           StringRef DemangledName) {
   StringRef Stem = DemangledName;
-  if (Stem.startswith("atomic_"))
+  if (Stem.starts_with("atomic_"))
     Stem = Stem.drop_front(strlen("atomic_"));
   else
     return;
 
   std::string NewStem(Stem);
   std::vector<int> PostOps;
-  if (Stem.startswith("store") || Stem.startswith("load") ||
-      Stem.startswith("exchange") || Stem.startswith("compare_exchange") ||
-      Stem.startswith("fetch") || Stem.startswith("flag")) {
-    if ((Stem.startswith("fetch_min") || Stem.startswith("fetch_max")) &&
+  if (Stem.starts_with("store") || Stem.starts_with("load") ||
+      Stem.starts_with("exchange") || Stem.starts_with("compare_exchange") ||
+      Stem.starts_with("fetch") || Stem.starts_with("flag")) {
+    if ((Stem.starts_with("fetch_min") || Stem.starts_with("fetch_max")) &&
         containsUnsignedAtomicType(MangledName))
       NewStem.insert(NewStem.begin() + strlen("fetch_"), 'u');
 
-    if (!Stem.endswith("_explicit")) {
+    if (!Stem.ends_with("_explicit")) {
       NewStem = NewStem + "_explicit";
       PostOps.push_back(OCLMO_seq_cst);
-      if (Stem.startswith("compare_exchange"))
+      if (Stem.starts_with("compare_exchange"))
         PostOps.push_back(OCLMO_seq_cst);
       PostOps.push_back(OCLMS_device);
     } else {
@@ -738,43 +724,26 @@ void OCLToSPIRVBase::visitCallBarrier(CallInst *CI) {
 
 void OCLToSPIRVBase::visitCallConvert(CallInst *CI, StringRef MangledName,
                                       StringRef DemangledName) {
-  // OpenCL Explicit Conversions (6.4.3) formed as below for scalars:
-  // destType convert_destType<_sat><_roundingMode>(sourceType)
-  // and for vector type:
-  // destTypeN convert_destTypeN<_sat><_roundingMode>(sourceTypeN)
-  // If the demangled name is not matching the suggested pattern and does not
-  // meet allowed destination type restrictions - this is not an OpenCL builtin,
-  // return from the function and translate such CallInst as a function call.
   if (eraseUselessConvert(CI, MangledName, DemangledName))
     return;
   Op OC = OpNop;
-  auto TargetTy = CI->getType();
-  auto SrcTy = CI->getArgOperand(0)->getType();
+  auto *TargetTy = CI->getType();
+  auto *SrcTy = CI->getArgOperand(0)->getType();
   if (auto *VecTy = dyn_cast<VectorType>(TargetTy))
     TargetTy = VecTy->getElementType();
   if (auto *VecTy = dyn_cast<VectorType>(SrcTy))
     SrcTy = VecTy->getElementType();
   auto IsTargetInt = isa<IntegerType>(TargetTy);
 
-  // Validate conversion function name and vector size if present
-  std::regex Expr(
-      "convert_(float|double|half|u?char|u?short|u?int|u?long)(2|3|4|8|16)*"
-      "(_sat)*(_rt[ezpn])*$");
-  std::smatch DestTyMatch;
-  std::string ConversionFunc(DemangledName.str());
-  if (!std::regex_match(ConversionFunc, DestTyMatch, Expr))
-    return;
-
-  // The first sub_match is the whole string; the next
-  // sub_matches are the parenthesized expressions.
-  enum { TypeIdx = 1, VecSizeIdx = 2, SatIdx = 3, RoundingIdx = 4 };
-  std::string DestTy = DestTyMatch[TypeIdx].str();
-  std::string VecSize = DestTyMatch[VecSizeIdx].str();
-  std::string Sat = DestTyMatch[SatIdx].str();
-  std::string Rounding = DestTyMatch[RoundingIdx].str();
-
-  bool TargetSigned = DestTy[0] != 'u';
+  std::string TargetTyName(
+      DemangledName.substr(strlen(kOCLBuiltinName::ConvertPrefix)));
+  auto FirstUnderscoreLoc = TargetTyName.find('_');
+  if (FirstUnderscoreLoc != std::string::npos)
+    TargetTyName = TargetTyName.substr(0, FirstUnderscoreLoc);
+  TargetTyName = std::string("_R") + TargetTyName;
 
+  std::string Sat = DemangledName.find("_sat") != StringRef::npos ? "_sat" : "";
+  auto TargetSigned = DemangledName[8] != 'u';
   if (isa<IntegerType>(SrcTy)) {
     bool Signed = isLastFuncParamSigned(MangledName);
     if (IsTargetInt) {
@@ -791,15 +760,18 @@ void OCLToSPIRVBase::visitCallConvert(CallInst *CI, StringRef MangledName,
     } else
       OC = OpFConvert;
   }
-
+  auto Loc = DemangledName.find("_rt");
+  std::string Rounding;
+  if (Loc != StringRef::npos && !(isa<IntegerType>(SrcTy) && IsTargetInt)) {
+    Rounding = DemangledName.substr(Loc, 4).str();
+  }
   assert(CI->getCalledFunction() && "Unexpected indirect call");
-  mutateCallInst(
-      CI, getSPIRVFuncName(OC, "_R" + DestTy + VecSize + Sat + Rounding));
+  mutateCallInst(CI, getSPIRVFuncName(OC, TargetTyName + Sat + Rounding));
 }
 
 void OCLToSPIRVBase::visitCallGroupBuiltin(CallInst *CI,
                                            StringRef OrigDemangledName) {
-  auto F = CI->getCalledFunction();
+  auto *F = CI->getCalledFunction();
   std::vector<int> PreOps;
   std::string DemangledName{OrigDemangledName};
 
@@ -821,7 +793,7 @@ void OCLToSPIRVBase::visitCallGroupBuiltin(CallInst *CI,
     FuncName = FuncName.drop_front(strlen(kSPIRVName::GroupPrefix));
     SPIRSPIRVGroupOperationMap::foreachConditional(
         [&](const std::string &S, SPIRVGroupOperationKind G) {
-          if (!FuncName.startswith(S))
+          if (!FuncName.starts_with(S))
             return true; // continue
           PreOps.push_back(G);
           StringRef Op =
@@ -842,7 +814,7 @@ void OCLToSPIRVBase::visitCallGroupBuiltin(CallInst *CI,
           (void)(GroupOp.consume_front("_")); // when op is two characters
           assert(!GroupOp.empty() && "Invalid OpenCL group builtin function");
           char OpTyC = 0;
-          auto OpTy = F->getReturnType();
+          auto *OpTy = F->getReturnType();
           if (OpTy->isFloatingPointTy())
             OpTyC = 'f';
           else if (OpTy->isIntegerTy()) {
@@ -915,7 +887,7 @@ void OCLToSPIRVBase::transBuiltin(CallInst *CI, OCLBuiltinTransInfo &Info) {
   Op OC = OpNop;
   unsigned ExtOp = ~0U;
   SPIRVBuiltinVariableKind BVKind = BuiltInMax;
-  if (StringRef(Info.UniqName).startswith(kSPIRVName::Prefix))
+  if (StringRef(Info.UniqName).starts_with(kSPIRVName::Prefix))
     return;
   if (OCLSPIRVBuiltinMap::find(Info.UniqName, &OC)) {
     if (OC == OpImageRead) {
@@ -941,16 +913,16 @@ void OCLToSPIRVBase::transBuiltin(CallInst *CI, OCLBuiltinTransInfo &Info) {
     Info.UniqName = getSPIRVFuncName(BVKind);
   } else
     return;
-  auto Mutator = mutateCallInst(CI, Info.UniqName + Info.Postfix);
+  BuiltinCallMutator Mutator = mutateCallInst(CI, Info.UniqName + Info.Postfix);
   Info.PostProc(Mutator);
   if (Info.RetTy) {
     Type *OldRetTy = CI->getType();
     Mutator.changeReturnType(
-        Info.RetTy, [&](IRBuilder<> &Builder, CallInst *NewCI) {
-          if (Info.RetTy->isIntegerTy() && OldRetTy->isIntegerTy())
+        Info.RetTy, [OldRetTy, &Info](IRBuilder<> &Builder, CallInst *NewCI) {
+          if (Info.RetTy->isIntegerTy() && OldRetTy->isIntegerTy()) {
             return Builder.CreateIntCast(NewCI, OldRetTy, Info.IsRetSigned);
-          else
-            return Builder.CreatePointerBitCastOrAddrSpaceCast(NewCI, OldRetTy);
+          }
+          return Builder.CreatePointerBitCastOrAddrSpaceCast(NewCI, OldRetTy);
         });
   }
 }
@@ -1041,7 +1013,7 @@ void OCLToSPIRVBase::visitCallGetImageSize(CallInst *CI,
           return NCI;
         if (DemangledName == kOCLBuiltinName::GetImageDim) {
           if (Desc.Dim == Dim3D) {
-            auto ZeroVec = ConstantVector::getSplat(
+            auto *ZeroVec = ConstantVector::getSplat(
                 ElementCount::getFixed(3),
                 Constant::getNullValue(
                     cast<VectorType>(NCI->getType())->getElementType()));
@@ -1071,8 +1043,8 @@ void OCLToSPIRVBase::visitCallGetImageSize(CallInst *CI,
 /// Remove trivial conversion functions
 bool OCLToSPIRVBase::eraseUselessConvert(CallInst *CI, StringRef MangledName,
                                          StringRef DemangledName) {
-  auto TargetTy = CI->getType();
-  auto SrcTy = CI->getArgOperand(0)->getType();
+  auto *TargetTy = CI->getType();
+  auto *SrcTy = CI->getArgOperand(0)->getType();
   if (auto *VecTy = dyn_cast<VectorType>(TargetTy))
     TargetTy = VecTy->getElementType();
   if (auto *VecTy = dyn_cast<VectorType>(SrcTy))
@@ -1087,7 +1059,6 @@ bool OCLToSPIRVBase::eraseUselessConvert(CallInst *CI, StringRef MangledName,
                     << *CI->getArgOperand(0) << '\n');
     CI->replaceAllUsesWith(CI->getArgOperand(0));
     ValuesToDelete.insert(CI);
-    ValuesToDelete.insert(CI->getCalledFunction());
     return true;
   }
   return false;
@@ -1108,8 +1079,9 @@ void OCLToSPIRVBase::visitCallReadWriteImage(CallInst *CI,
     Info.UniqName = kOCLBuiltinName::ReadImage;
     unsigned ImgOpMask = getImageSignZeroExt(DemangledName);
     if (ImgOpMask) {
-      Info.PostProc = [&](BuiltinCallMutator &Mutator) {
-        Mutator.appendArg(getInt32(M, ImgOpMask));
+      Module *Mod = M;
+      Info.PostProc = [ImgOpMask, Mod](BuiltinCallMutator &Mutator) {
+        Mutator.appendArg(getInt32(Mod, ImgOpMask));
       };
     }
   }
@@ -1141,7 +1113,7 @@ void OCLToSPIRVBase::visitCallToAddr(CallInst *CI, StringRef DemangledName) {
   Info.UniqName = DemangledName.str();
   Info.Postfix = std::string(kSPIRVPostfix::Divider) + "To" +
                  SPIRAddrSpaceCapitalizedNameMap::map(AddrSpace);
-  auto StorageClass = addInt32(SPIRSPIRVAddrSpaceMap::map(AddrSpace));
+  auto *StorageClass = addInt32(SPIRSPIRVAddrSpaceMap::map(AddrSpace));
   Info.RetTy = getInt8PtrTy(cast<PointerType>(CI->getType()));
   Info.PostProc = [=](BuiltinCallMutator &Mutator) {
     Mutator
@@ -1251,7 +1223,7 @@ void OCLToSPIRVBase::visitCallDot(CallInst *CI, StringRef MangledName,
       // dot(short2, ushort2) _Z3dotDv2_sDv2_t
       // dot(ushort2, short2) _Z3dotDv2_tDv2_s
       // dot(ushort2, ushort2) _Z3dotDv2_tS_
-      assert(MangledName.startswith("_Z3dotDv"));
+      assert(MangledName.starts_with("_Z3dotDv"));
       if (MangledName[MangledName.size() - 1] == '_') {
         IsFirstSigned = ((MangledName[MangledName.size() - 3] == 'c') ||
                          (MangledName[MangledName.size() - 3] == 's'));
@@ -1272,7 +1244,7 @@ void OCLToSPIRVBase::visitCallDot(CallInst *CI, StringRef MangledName,
       // dot_acc_sat(short2, ushort2, int) _Z11dot_acc_satDv4_sDv4_ti
       // dot_acc_sat(ushort2, short2, int) _Z11dot_acc_satDv4_tDv4_si
       // dot_acc_sat(ushort2, ushort2, uint) _Z11dot_acc_satDv4_tS_j
-      assert(MangledName.startswith("_Z11dot_acc_satDv"));
+      assert(MangledName.starts_with("_Z11dot_acc_satDv"));
       IsFirstSigned = ((MangledName[19] == 'c') || (MangledName[19] == 's'));
       IsSecondSigned = (MangledName[20] == 'S'
                             ? IsFirstSigned
@@ -1294,10 +1266,10 @@ void OCLToSPIRVBase::visitCallDot(CallInst *CI, StringRef MangledName,
     // _Z28dot_acc_sat_4x8packed_us_intjji
     // dot_acc_sat_4x8packed_uu_uint(uint, uint, uint)
     // _Z29dot_acc_sat_4x8packed_uu_uintjjj
-    assert(MangledName.startswith("_Z20dot_4x8packed") ||
-           MangledName.startswith("_Z21dot_4x8packed") ||
-           MangledName.startswith("_Z28dot_acc_sat_4x8packed") ||
-           MangledName.startswith("_Z29dot_acc_sat_4x8packed"));
+    assert(MangledName.starts_with("_Z20dot_4x8packed") ||
+           MangledName.starts_with("_Z21dot_4x8packed") ||
+           MangledName.starts_with("_Z28dot_acc_sat_4x8packed") ||
+           MangledName.starts_with("_Z29dot_acc_sat_4x8packed"));
     size_t SignIndex = IsAccSat
                            ? strlen(kOCLBuiltinName::DotAccSat4x8PackedPrefix)
                            : strlen(kOCLBuiltinName::Dot4x8PackedPrefix);
@@ -1387,10 +1359,56 @@ void OCLToSPIRVBase::visitCallScalToVec(CallInst *CI, StringRef MangledName,
     });
 }
 
+namespace {
+// Return true if any users of the CallInst use any of the constants
+// introduced by the SPV_EXT_image_raw10_raw12 extension.
+bool usesSpvExtImageRaw10Raw12Constants(const CallInst *CI) {
+  const std::array ExtConstants{
+      OCLImageChannelDataTypeOffset + ImageChannelDataTypeUnsignedIntRaw10EXT,
+      OCLImageChannelDataTypeOffset + ImageChannelDataTypeUnsignedIntRaw12EXT};
+
+  // The return values for `OpImageQueryFormat` added by the extension are
+  // integer constants that may appear anywhere in LLVM IR.  Only detect some
+  // common use patterns here.
+  for (auto *U : CI->users()) {
+    for (auto C : ExtConstants) {
+      ICmpInst::Predicate Pred;
+      if (match(U, m_c_ICmp(Pred, m_Value(), m_SpecificInt(C)))) {
+        return true;
+      }
+      if (auto *Switch = dyn_cast<SwitchInst>(U)) {
+        if (any_of(Switch->cases(), [C](const auto &Case) {
+              return Case.getCaseValue()->equalsInt(C);
+            })) {
+          return true;
+        }
+      }
+    }
+  }
+  return false;
+}
+} // anonymous namespace
+
 void OCLToSPIRVBase::visitCallGetImageChannel(CallInst *CI,
                                               StringRef DemangledName,
                                               unsigned int Offset) {
   assert(CI->getCalledFunction() && "Unexpected indirect call");
+
+  if (Offset == OCLImageChannelDataTypeOffset) {
+    // See if any of the SPV_EXT_image_raw10_raw12 constants are used, and
+    // add the extension if not already there.
+    if (usesSpvExtImageRaw10Raw12Constants(CI)) {
+      const char *ExtStr = "SPV_EXT_image_raw10_raw12";
+      NamedMDNode *NMD = M->getOrInsertNamedMetadata(kSPIRVMD::Extension);
+      if (none_of(NMD->operands(), [ExtStr](MDNode *N) {
+            return N->getOperand(0).equalsStr(ExtStr);
+          })) {
+        MDString *MDS = MDString::get(*Ctx, ExtStr);
+        NMD->addOperand(MDNode::get(*Ctx, MDS));
+      }
+    }
+  }
+
   Op OC = OpNop;
   OCLSPIRVBuiltinMap::find(DemangledName.str(), &OC);
   mutateCallInst(CI, OC).changeReturnType(
@@ -1565,11 +1583,11 @@ static const char *getSubgroupAVCIntelTyKind(StringRef MangledName) {
   // We're looking for the type name of the last parameter, which will be at the
   // very end of the mangled name. Since we only care about the ending of the
   // name, we don't need to be any more clever than this.
-  return MangledName.endswith("_payload_t") ? "payload" : "result";
+  return MangledName.ends_with("_payload_t") ? "payload" : "result";
 }
 
 static Type *getSubgroupAVCIntelMCEType(Module *M, std::string &TName) {
-  auto Ty = StructType::getTypeByName(M->getContext(), TName);
+  auto *Ty = StructType::getTypeByName(M->getContext(), TName);
   if (Ty)
     return Ty;
 
