@@ -189,7 +189,6 @@ enum SPIRAddressSpace {
   SPIRAS_GlobalHost,
   SPIRAS_Input,
   SPIRAS_Output,
-  SPIRAS_CodeSectionINTEL,
   SPIRAS_Count,
 };
 
@@ -200,8 +199,6 @@ template <> inline void SPIRVMap<SPIRAddressSpace, std::string>::init() {
   add(SPIRAS_Local, "Local");
   add(SPIRAS_Generic, "Generic");
   add(SPIRAS_Input, "Input");
-  add(SPIRAS_CodeSectionINTEL, "CodeSectionINTEL");
-
   add(SPIRAS_GlobalDevice, "GlobalDevice");
   add(SPIRAS_GlobalHost, "GlobalHost");
 }
@@ -218,7 +215,6 @@ inline void SPIRVMap<SPIRAddressSpace, SPIRVStorageClassKind>::init() {
   add(SPIRAS_Input, StorageClassInput);
   add(SPIRAS_GlobalDevice, StorageClassDeviceOnlyINTEL);
   add(SPIRAS_GlobalHost, StorageClassHostOnlyINTEL);
-  add(SPIRAS_CodeSectionINTEL, StorageClassCodeSectionINTEL);
 }
 typedef SPIRVMap<SPIRAddressSpace, SPIRVStorageClassKind> SPIRSPIRVAddrSpaceMap;
 
@@ -251,7 +247,7 @@ inline void
 SPIRVMap<Attribute::AttrKind, SPIRVFunctionControlMaskKind>::init() {
   add(Attribute::AlwaysInline, FunctionControlInlineMask);
   add(Attribute::NoInline, FunctionControlDontInlineMask);
-  add(Attribute::OptimizeNone, FunctionControlOptNoneEXTMask);
+  add(Attribute::OptimizeNone, internal::FunctionControlOptNoneINTELMask);
 }
 typedef SPIRVMap<Attribute::AttrKind, SPIRVFunctionControlMaskKind>
     SPIRSPIRVFuncCtlMaskMap;
@@ -295,8 +291,6 @@ const static char Float[] = "float";
 const static char Half[] = "half";
 const static char Int[] = "int";
 const static char UInt[] = "uint";
-const static char Long[] = "long";
-const static char ULong[] = "ulong";
 const static char Void[] = "void";
 } // namespace kSPIRVImageSampledTypeName
 
@@ -369,11 +363,6 @@ const static char TranslateSPIRVMemOrder[] = "__translate_spirv_memory_order";
 const static char TranslateSPIRVMemScope[] = "__translate_spirv_memory_scope";
 const static char TranslateSPIRVMemFence[] = "__translate_spirv_memory_fence";
 const static char EntrypointPrefix[] = "__spirv_entry_";
-const static char ConvertHandleToImageINTEL[] = "ConvertHandleToImageINTEL";
-const static char ConvertHandleToSamplerINTEL[] = "ConvertHandleToSamplerINTEL";
-const static char ConvertHandleToSampledImageINTEL[] =
-    "ConvertHandleToSampledImageINTEL";
-const static char InternalBuiltinPrefix[] = "__builtin_spirv_";
 } // namespace kSPIRVName
 
 namespace kSPIRVPostfix {
@@ -418,13 +407,14 @@ const static char NoGlobalOffset[] = "no_global_work_offset";
 const static char MaxWGDim[] = "max_global_work_dim";
 const static char NumSIMD[] = "num_simd_work_items";
 const static char StallEnable[] = "stall_enable";
+const static char StallFree[] = "stall_free";
 const static char FmaxMhz[] = "scheduler_target_fmax_mhz";
 const static char LoopFuse[] = "loop_fuse";
 const static char PreferDSP[] = "prefer_dsp";
 const static char PropDSPPref[] = "propagate_dsp_preference";
 const static char InitiationInterval[] = "initiation_interval";
 const static char MaxConcurrency[] = "max_concurrency";
-const static char DisableLoopPipelining[] = "disable_loop_pipelining";
+const static char PipelineKernel[] = "pipeline_kernel";
 const static char IntelFPGAIPInterface[] = "ip_interface";
 } // namespace kSPIR2MD
 
@@ -601,10 +591,6 @@ template <typename T> T getArgAs(CallInst *CI, unsigned I) {
 /// \param I argument index.
 Scope getArgAsScope(CallInst *CI, unsigned I);
 
-/// Get constant function call argument as a Decoration enum.
-/// \param I argument index.
-Decoration getArgAsDecoration(CallInst *CI, unsigned I);
-
 /// Check if a type is OCL image type.
 /// \return type name without "opencl." prefix.
 bool isOCLImageType(llvm::Type *Ty, StringRef *Name = nullptr);
@@ -619,12 +605,6 @@ bool isSYCLHalfType(llvm::Type *Ty);
 
 bool isSYCLBfloat16Type(llvm::Type *Ty);
 
-/// Decorate a function name as __spirv_{Name}_
-std::string decorateSPIRVFunction(const std::string &S);
-
-/// Remove prefix/postfix from __spirv_{Name}_
-StringRef undecorateSPIRVFunction(StringRef S);
-
 /// Check if a function has decorated name as __spirv_{Name}_
 /// and get the original name.
 bool isDecoratedSPIRVFunc(const Function *F, StringRef &UndecName);
@@ -660,7 +640,7 @@ Op getSPIRVFuncOC(StringRef Name, SmallVectorImpl<std::string> *Dec = nullptr);
 bool getSPIRVBuiltin(const std::string &Name, spv::BuiltIn &Builtin);
 
 /// \param Name LLVM function name
-/// \param DemangledName demangled name of the OpenCL built-in function
+/// \param DemangledName demanged name of the OpenCL built-in function
 /// \returns true if Name is the name of the OpenCL built-in function,
 /// false for other functions
 bool oclIsBuiltin(StringRef Name, StringRef &DemangledName, bool IsCpp = false);
@@ -723,9 +703,6 @@ CallInst *addCallInst(Module *M, StringRef FuncName, Type *RetTy,
                       StringRef InstName = SPIR_TEMP_NAME_PREFIX_CALL,
                       bool TakeFuncName = true);
 
-/// Check if an LLVM type is spirv.CooperativeMatrixKHR.
-bool isLLVMCooperativeMatrixType(llvm::Type *Ty);
-
 /// Add a call instruction for SPIR-V builtin function.
 CallInst *addCallInstSPIRV(Module *M, StringRef FuncName, Type *RetTy,
                            ArrayRef<Value *> Args, AttributeList *Attrs,
@@ -746,12 +723,6 @@ void makeVector(Instruction *InsPos, std::vector<Value *> &Ops,
 /// Get size_t type.
 IntegerType *getSizetType(Module *M);
 
-/// Get void(void) function type.
-Type *getVoidFuncType(Module *M);
-
-/// Get void(void) function pointer type.
-Type *getVoidFuncPtrType(Module *M, unsigned AddrSpace = 0);
-
 /// Get a 64 bit integer constant.
 ConstantInt *getInt64(Module *M, int64_t Value);
 
@@ -808,17 +779,6 @@ std::set<std::string> getNamedMDAsStringSet(Module *M,
 /// Get SPIR-V language by SPIR-V metadata spirv.Source
 std::tuple<unsigned, unsigned, std::string> getSPIRVSource(Module *M);
 
-/// Map an unsigned integer constant by applying a function.
-ConstantInt *mapUInt(Module *M, ConstantInt *I,
-                     std::function<unsigned(unsigned)> F);
-
-/// Map a signed integer constant by applying a function.
-ConstantInt *mapSInt(Module *M, ConstantInt *I, std::function<int(int)> F);
-
-/// Get postfix for given decoration.
-/// The returned postfix does not include "_" at the beginning.
-std::string getPostfix(Decoration Dec, unsigned Value = 0);
-
 /// Get postfix _R{ReturnType} for return type
 /// The returned postfix does not includ "_" at the beginning
 std::string getPostfixForReturnType(CallInst *CI, bool IsSigned = false);
@@ -849,10 +809,6 @@ std::string getSPIRVTypeName(StringRef BaseTyName, StringRef Postfixes = "");
 /// Checks if given type name is either ConstantSampler or ConsantPipeStorage.
 bool isSPIRVConstantName(StringRef TyName);
 
-/// Get the sampled type name used in postfix of image type in SPIR-V
-/// friendly LLVM IR.
-std::string getSPIRVImageSampledTypeName(SPIRVType *Ty);
-
 /// Get LLVM type for sampled type of SPIR-V image type by postfix.
 Type *getLLVMTypeForSPIRVImageSampledTypePostfix(StringRef Postfix,
                                                  LLVMContext &Ctx);
@@ -884,8 +840,6 @@ bool eraseUselessFunctions(Module *M);
 /// Erase a function if it is declaration, has internal linkage and has no use.
 bool eraseIfNoUse(Function *F);
 
-void eraseIfNoUse(Value *V);
-
 // Check if a mangled type name is unsigned
 bool isMangledTypeUnsigned(char Mangled);
 
@@ -928,6 +882,13 @@ inline bool getParameterTypes(CallInst *CI, SmallVectorImpl<Type *> &ArgTys) {
   return getParameterTypes(CI->getCalledFunction(), ArgTys);
 }
 
+enum class ParamSignedness { Signed = 0, Unsigned, Unknown };
+
+/// Extract signedness of return type and parameter types from a mangled
+/// function name.
+bool getRetParamSignedness(Function *F, ParamSignedness &RetSignedness,
+                           SmallVectorImpl<ParamSignedness> &ArgSignedness);
+
 /// Mangle a function from OpenCL extended instruction set in SPIR-V friendly IR
 /// manner
 std::string getSPIRVFriendlyIRFunctionName(OCLExtOpKind ExtOpId,
@@ -947,9 +908,6 @@ std::string getSPIRVFriendlyIRFunctionName(const std::string &UniqName,
                                            spv::Op OC, ArrayRef<Type *> ArgTys,
                                            ArrayRef<SPIRVValue *> Ops);
 
-/// Cast a function to a void(void) funtion pointer.
-Constant *castToVoidFuncPtr(Function *F);
-
 /// Get i8* with the same address space.
 PointerType *getInt8PtrTy(PointerType *T);
 
@@ -1044,169 +1002,6 @@ bool postProcessBuiltinsReturningStruct(Module *M, bool IsCpp = false);
 
 bool postProcessBuiltinsWithArrayArguments(Module *M, bool IsCpp = false);
 
-template <typename T>
-MetadataAsValue *map2MDString(LLVMContext &C, SPIRVValue *V);
-
-/// \param MangledName LLVM function name.
-/// \param DemangledName demangled name of the input function if it is the
-/// translator's internal built-in function.
-/// \returns true if MangledName is the name of the translator's internal
-/// built-in function, false for other functions.
-/// Used for 'mini'-floats conversion functions
-bool isInternalSPIRVBuiltin(StringRef MangledName, std::string &DemangledName);
-
-// Wrapper around SPIR-V 1.6.4 FP Encoding to be used in the conversion
-// descriptor
-enum FPEncodingWrap {
-  Integer = FPEncoding::FPEncodingMax - 1,
-  IEEE754 = FPEncoding::FPEncodingMax,
-  BF16 = FPEncoding::FPEncodingBFloat16KHR,
-  E4M3 = FPEncoding::FPEncodingFloat8E4M3EXT,
-  E5M2 = FPEncoding::FPEncodingFloat8E5M2EXT,
-  E2M1 = internal::FPEncodingFloat4E2M1INTEL,
-};
-
-// Structure describing non-trivial conversions (FP8 and int4)
-struct FPConversionDesc {
-  FPEncodingWrap SrcEncoding;
-  FPEncodingWrap DstEncoding;
-  SPIRVWord ConvOpCode;
-
-  // To use as a key in std::map
-  bool operator==(const FPConversionDesc &Other) const {
-    return SrcEncoding == Other.SrcEncoding &&
-           DstEncoding == Other.DstEncoding && ConvOpCode == Other.ConvOpCode;
-  }
-
-  bool operator<(const FPConversionDesc &Other) const {
-    if (ConvOpCode != Other.ConvOpCode)
-      return ConvOpCode < Other.ConvOpCode;
-    if (SrcEncoding != Other.SrcEncoding)
-      return SrcEncoding < Other.SrcEncoding;
-    return DstEncoding < Other.DstEncoding;
-  }
-};
-
-// Maps internal builtin name to conversion descriptor
-typedef SPIRVMap<llvm::StringRef, FPConversionDesc> FPConvertToEncodingMap;
-
-// clang-format off
-template <> inline void FPConvertToEncodingMap::init() {
-  // 4-bit conversions
-  add("ConvertE2M1ToE4M3INTEL",
-      {FPEncodingWrap::E2M1,      FPEncodingWrap::E4M3,         OpFConvert});
-  add("ConvertE2M1ToE5M2INTEL",
-      {FPEncodingWrap::E2M1,      FPEncodingWrap::E5M2,         OpFConvert});
-  add("ConvertE2M1ToFP16INTEL",
-      {FPEncodingWrap::E2M1,      FPEncodingWrap::IEEE754,      OpFConvert});
-  add("ConvertE2M1ToBF16INTEL",
-      {FPEncodingWrap::E2M1,      FPEncodingWrap::BF16,         OpFConvert});
-
-  add("ConvertInt4ToE4M3INTEL",
-      {FPEncodingWrap::Integer,      FPEncodingWrap::E4M3,      OpConvertSToF});
-  add("ConvertInt4ToE5M2INTEL",
-      {FPEncodingWrap::Integer,      FPEncodingWrap::E5M2,      OpConvertSToF});
-  add("ConvertInt4ToFP16INTEL",
-      {FPEncodingWrap::Integer,      FPEncodingWrap::IEEE754,   OpConvertSToF});
-  add("ConvertInt4ToBF16INTEL",
-      {FPEncodingWrap::Integer,      FPEncodingWrap::BF16,      OpConvertSToF});
-  add("ConvertInt4ToInt8INTEL",
-      {FPEncodingWrap::Integer,      FPEncodingWrap::Integer,   OpSConvert});
-
-  add("ConvertFP16ToE2M1INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::E2M1,      OpFConvert});
-  add("ConvertBF16ToE2M1INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::E2M1,      OpFConvert});
-  add("ConvertFP16ToInt4INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::Integer,   OpConvertFToS});
-  add("ConvertBF16ToInt4INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::Integer,   OpConvertFToS});
-
-  // 8-bit conversions
-  add("ConvertE4M3ToFP16EXT",
-      {FPEncodingWrap::E4M3,         FPEncodingWrap::IEEE754,      OpFConvert});
-  add("ConvertE5M2ToFP16EXT",
-      {FPEncodingWrap::E5M2,         FPEncodingWrap::IEEE754,      OpFConvert});
-  add("ConvertE4M3ToBF16EXT",
-      {FPEncodingWrap::E4M3,         FPEncodingWrap::BF16,         OpFConvert});
-  add("ConvertE5M2ToBF16EXT",
-      {FPEncodingWrap::E5M2,         FPEncodingWrap::BF16,         OpFConvert});
-  add("ConvertFP16ToE4M3EXT",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::E4M3,         OpFConvert});
-  add("ConvertFP16ToE5M2EXT",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::E5M2,         OpFConvert});
-  add("ConvertBF16ToE4M3EXT",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::E4M3,         OpFConvert});
-  add("ConvertBF16ToE5M2EXT",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::E5M2,         OpFConvert});
-
-  // SPV_INTEL_fp_conversions
-  add("ClampConvertFP16ToE2M1INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::E2M1,
-       internal::OpClampConvertFToFINTEL});
-  add("ClampConvertBF16ToE2M1INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::E2M1,
-       internal::OpClampConvertFToFINTEL});
-  add("ClampConvertFP16ToE4M3INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::E4M3,
-       internal::OpClampConvertFToFINTEL});
-  add("ClampConvertBF16ToE4M3INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::E4M3,
-       internal::OpClampConvertFToFINTEL});
-  add("ClampConvertFP16ToE5M2INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::E5M2,
-       internal::OpClampConvertFToFINTEL});
-  add("ClampConvertBF16ToE5M2INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::E5M2,
-       internal::OpClampConvertFToFINTEL});
-  add("ClampConvertFP16ToInt4INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::Integer,
-       internal::OpClampConvertFToSINTEL});
-  add("ClampConvertBF16ToInt4INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::Integer,
-       internal::OpClampConvertFToSINTEL});
-
-  add("StochasticRoundFP16ToE5M2INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::E5M2,
-       internal::OpStochasticRoundFToFINTEL});
-  add("StochasticRoundFP16ToE4M3INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::E4M3,
-       internal::OpStochasticRoundFToFINTEL});
-  add("StochasticRoundBF16ToE5M2INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::E5M2,
-       internal::OpStochasticRoundFToFINTEL});
-  add("StochasticRoundBF16ToE4M3INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::E4M3,
-       internal::OpStochasticRoundFToFINTEL});
-  add("StochasticRoundFP16ToE2M1INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::E2M1,
-       internal::OpStochasticRoundFToFINTEL});
-  add("StochasticRoundBF16ToE2M1INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::E2M1,
-       internal::OpStochasticRoundFToFINTEL});
-  add("ClampStochasticRoundFP16ToInt4INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::Integer,
-       internal::OpClampStochasticRoundFToSINTEL});
-  add("ClampStochasticRoundBF16ToInt4INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::Integer,
-       internal::OpClampStochasticRoundFToSINTEL});
-
-  add("ClampStochasticRoundFP16ToE5M2INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::E5M2,
-       internal::OpClampStochasticRoundFToFINTEL});
-  add("ClampStochasticRoundFP16ToE4M3INTEL",
-      {FPEncodingWrap::IEEE754,      FPEncodingWrap::E4M3,
-       internal::OpClampStochasticRoundFToFINTEL});
-  add("ClampStochasticRoundBF16ToE5M2INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::E5M2,
-       internal::OpClampStochasticRoundFToFINTEL});
-  add("ClampStochasticRoundBF16ToE4M3INTEL",
-      {FPEncodingWrap::BF16,         FPEncodingWrap::E4M3,
-       internal::OpClampStochasticRoundFToFINTEL});
-}
-
-// clang-format on
-
 } // namespace SPIRV
 
 #endif // SPIRV_SPIRVINTERNAL_H
