@@ -37,7 +37,6 @@
 //===----------------------------------------------------------------------===//
 
 #include "SPIRVToLLVMDbgTran.h"
-#include "SPIRV.debug.h"
 #include "SPIRVEntry.h"
 #include "SPIRVFunction.h"
 #include "SPIRVInstruction.h"
@@ -152,10 +151,8 @@ SPIRVToLLVMDbgTran::getStringSourceContinued(const SPIRVId Id,
 }
 
 void SPIRVToLLVMDbgTran::transDbgInfo(const SPIRVValue *SV, Value *V) {
-  // Constant samplers and composites do not have a corresponding
-  // SPIRVInstruction, but they may be mapped to an LLVM Instruction.
-  if (SV->getOpCode() == OpConstantSampler ||
-      SV->getOpCode() == OpConstantComposite)
+  // A constant sampler does not have a corresponding SPIRVInstruction.
+  if (SV->getOpCode() == OpConstantSampler)
     return;
 
   if (Instruction *I = dyn_cast<Instruction>(V)) {
@@ -355,7 +352,7 @@ SPIRVToLLVMDbgTran::transTypeArrayOpenCL(const SPIRVExtInst *DebugInst) {
   const SPIRVWordVec &Ops = DebugInst->getArguments();
   assert(Ops.size() >= MinOperandCount && "Invalid number of operands");
   DIType *BaseTy =
-      transNonNullDebugType(BM->get<SPIRVExtInst>(Ops[BaseTypeIdx]));
+      transDebugInst<DIType>(BM->get<SPIRVExtInst>(Ops[BaseTypeIdx]));
   size_t TotalCount = 1;
   SmallVector<llvm::Metadata *, 8> Subscripts;
   // Ops looks like: { BaseType, count1|upperBound1, count2|upperBound2, ...,
@@ -415,7 +412,7 @@ SPIRVToLLVMDbgTran::transTypeArrayNonSemantic(const SPIRVExtInst *DebugInst) {
   const SPIRVWordVec &Ops = DebugInst->getArguments();
   assert(Ops.size() >= MinOperandCount && "Invalid number of operands");
   DIType *BaseTy =
-      transNonNullDebugType(BM->get<SPIRVExtInst>(Ops[BaseTypeIdx]));
+      transDebugInst<DIType>(BM->get<SPIRVExtInst>(Ops[BaseTypeIdx]));
   size_t TotalCount = 1;
   SmallVector<llvm::Metadata *, 8> Subscripts;
   if (DebugInst->getExtOp() == SPIRVDebug::TypeArray) {
@@ -439,7 +436,7 @@ SPIRVToLLVMDbgTran::transTypeArrayDynamic(const SPIRVExtInst *DebugInst) {
   const SPIRVWordVec &Ops = DebugInst->getArguments();
   assert(Ops.size() >= MinOperandCount && "Invalid number of operands");
   DIType *BaseTy =
-      transNonNullDebugType(BM->get<SPIRVExtInst>(Ops[BaseTypeIdx]));
+      transDebugInst<DIType>(BM->get<SPIRVExtInst>(Ops[BaseTypeIdx]));
   size_t TotalCount = 1;
   SmallVector<llvm::Metadata *, 8> Subscripts;
   for (size_t I = SubrangesIdx; I < Ops.size(); ++I) {
@@ -482,16 +479,18 @@ SPIRVToLLVMDbgTran::transTypeVector(const SPIRVExtInst *DebugInst) {
   const SPIRVWordVec &Ops = DebugInst->getArguments();
   assert(Ops.size() >= MinOperandCount && "Invalid number of operands");
   DIType *BaseTy =
-      transNonNullDebugType(BM->get<SPIRVExtInst>(Ops[BaseTypeIdx]));
+      transDebugInst<DIType>(BM->get<SPIRVExtInst>(Ops[BaseTypeIdx]));
   SPIRVWord Count = getConstantValueOrLiteral(Ops, ComponentCountIdx,
                                               DebugInst->getExtSetKind());
-  // Round up to a power of two.
-  // OpenCL/SYCL 3-element vectors
-  // occupy the same amount of memory as 4-element vectors
-  // Clang rounds up the memory size of vectors to a power of 2.
-  // Vulkan allows vec3 to have a memory size of 12, but in RenderDoc memory
-  // size is not derived from debug info.
-  uint64_t Size = getDerivedSizeInBits(BaseTy) * llvm::bit_ceil(Count);
+  // FIXME: The current design of SPIR-V Debug Info doesn't provide a field
+  // for the derived memory size. Meanwhile, OpenCL/SYCL 3-element vectors
+  // occupy the same amount of memory as 4-element vectors, hence the simple
+  // elem_count * elem_size formula fails in this edge case.
+  // Once the specification is updated to reflect the whole memory block's
+  // size in SPIR-V, the calculations below must be replaced with a simple
+  // translation of the known size.
+  SPIRVWord SizeCount = (Count == 3) ? 4 : Count;
+  uint64_t Size = getDerivedSizeInBits(BaseTy) * SizeCount;
 
   SmallVector<llvm::Metadata *, 8> Subscripts;
   Subscripts.push_back(getDIBuilder(DebugInst).getOrCreateSubrange(0, Count));
@@ -687,7 +686,8 @@ SPIRVToLLVMDbgTran::transTypeMemberOpenCL(const SPIRVExtInst *DebugInst) {
       getConstantValueOrLiteral(Ops, LineIdx, DebugInst->getExtSetKind());
   StringRef Name = getString(Ops[NameIdx]);
   DIScope *Scope = getScope(BM->getEntry(Ops[ParentIdx]));
-  DIType *BaseType = transNonNullDebugType(BM->get<SPIRVExtInst>(Ops[TypeIdx]));
+  DIType *BaseType =
+      transDebugInst<DIType>(BM->get<SPIRVExtInst>(Ops[TypeIdx]));
   uint64_t OffsetInBits =
       BM->get<SPIRVConstant>(Ops[OffsetIdx])->getZExtIntValue();
   SPIRVWord SPIRVFlags =
@@ -702,13 +702,19 @@ SPIRVToLLVMDbgTran::transTypeMemberOpenCL(const SPIRVExtInst *DebugInst) {
   }
   if (SPIRVFlags & SPIRVDebug::FlagIsStaticMember)
     Flags |= DINode::FlagStaticMember;
-  if (Flags & DINode::FlagStaticMember && Ops.size() > MinOperandCount) {
-    SPIRVValue *ConstVal = BM->get<SPIRVValue>(Ops[ValueIdx]);
-    assert(isConstantOpCode(ConstVal->getOpCode()) &&
-           "Static member must be a constant");
-    llvm::Value *Val = SPIRVReader->transValue(ConstVal, nullptr, nullptr);
+  if (Flags & DINode::FlagStaticMember) {
+    llvm::Value *Val = nullptr;
+    if (Ops.size() > MinOperandCount) {
+      SPIRVValue *ConstVal = BM->get<SPIRVValue>(Ops[ValueIdx]);
+      assert(isConstantOpCode(ConstVal->getOpCode()) &&
+             "Static member must be a constant");
+      Val = SPIRVReader->transValue(ConstVal, nullptr, nullptr);
+    }
+    auto Tag = M->getDwarfVersion() >= 5 ? llvm::dwarf::DW_TAG_variable
+                                         : llvm::dwarf::DW_TAG_member;
     return getDIBuilder(DebugInst).createStaticMemberType(
-        Scope, Name, File, LineNo, BaseType, Flags, cast<llvm::Constant>(Val));
+        Scope, Name, File, LineNo, BaseType, Flags,
+        cast_or_null<llvm::Constant>(Val), Tag);
   }
   uint64_t Size = BM->get<SPIRVConstant>(Ops[SizeIdx])->getZExtIntValue();
   uint64_t Alignment = 0;
@@ -733,7 +739,8 @@ SPIRVToLLVMDbgTran::transTypeMemberNonSemantic(const SPIRVExtInst *DebugInst,
   SPIRVWord LineNo =
       getConstantValueOrLiteral(Ops, LineIdx, DebugInst->getExtSetKind());
   StringRef Name = getString(Ops[NameIdx]);
-  DIType *BaseType = transNonNullDebugType(BM->get<SPIRVExtInst>(Ops[TypeIdx]));
+  DIType *BaseType =
+      transDebugInst<DIType>(BM->get<SPIRVExtInst>(Ops[TypeIdx]));
   uint64_t OffsetInBits =
       BM->get<SPIRVConstant>(Ops[OffsetIdx])->getZExtIntValue();
   SPIRVWord SPIRVFlags =
@@ -751,13 +758,19 @@ SPIRVToLLVMDbgTran::transTypeMemberNonSemantic(const SPIRVExtInst *DebugInst,
   if (SPIRVFlags & SPIRVDebug::FlagBitField)
     Flags |= DINode::FlagBitField;
 
-  if (Flags & DINode::FlagStaticMember && Ops.size() > MinOperandCount) {
-    SPIRVValue *ConstVal = BM->get<SPIRVValue>(Ops[ValueIdx]);
-    assert(isConstantOpCode(ConstVal->getOpCode()) &&
-           "Static member must be a constant");
-    llvm::Value *Val = SPIRVReader->transValue(ConstVal, nullptr, nullptr);
+  if (Flags & DINode::FlagStaticMember) {
+    llvm::Value *Val = nullptr;
+    if (Ops.size() > MinOperandCount) {
+      SPIRVValue *ConstVal = BM->get<SPIRVValue>(Ops[ValueIdx]);
+      assert(isConstantOpCode(ConstVal->getOpCode()) &&
+             "Static member must be a constant");
+      Val = SPIRVReader->transValue(ConstVal, nullptr, nullptr);
+    }
+    auto Tag = M->getDwarfVersion() >= 5 ? llvm::dwarf::DW_TAG_variable
+                                         : llvm::dwarf::DW_TAG_member;
     return getDIBuilder(DebugInst).createStaticMemberType(
-        Scope, Name, File, LineNo, BaseType, Flags, cast<llvm::Constant>(Val));
+        Scope, Name, File, LineNo, BaseType, Flags,
+        cast_or_null<llvm::Constant>(Val), Tag);
   }
   uint64_t Size = BM->get<SPIRVConstant>(Ops[SizeIdx])->getZExtIntValue();
   uint64_t Alignment = 0;
@@ -799,7 +812,7 @@ DINode *SPIRVToLLVMDbgTran::transTypeEnum(const SPIRVExtInst *DebugInst) {
       UnderlyingType = transDebugInst<DIType>(static_cast<SPIRVExtInst *>(E));
     return getDIBuilder(DebugInst).createEnumerationType(
         Scope, Name, File, LineNo, SizeInBits, AlignInBits, Enumerators,
-        UnderlyingType, "", Flags & SPIRVDebug::FlagIsEnumClass);
+        UnderlyingType, 0, "", UnderlyingType);
   }
 }
 
@@ -840,9 +853,9 @@ SPIRVToLLVMDbgTran::transTypePtrToMember(const SPIRVExtInst *DebugInst) {
   const SPIRVWordVec &Ops = DebugInst->getArguments();
   assert(Ops.size() >= OperandCount && "Invalid number of operands");
   SPIRVExtInst *Member = BM->get<SPIRVExtInst>(Ops[MemberTypeIdx]);
-  DIType *PointeeTy = transNonNullDebugType(Member);
+  DIType *PointeeTy = transDebugInst<DIType>(Member);
   SPIRVExtInst *ContainingTy = BM->get<SPIRVExtInst>(Ops[ParentIdx]);
-  DIType *BaseTy = transNonNullDebugType(ContainingTy);
+  DIType *BaseTy = transDebugInst<DIType>(ContainingTy);
   return getDIBuilder(DebugInst).createMemberPointerType(PointeeTy, BaseTy, 0);
 }
 
@@ -1103,7 +1116,7 @@ MDNode *SPIRVToLLVMDbgTran::transGlobalVariable(const SPIRVExtInst *DebugInst) {
   assert(Ops.size() >= MinOperandCount && "Invalid number of operands");
 
   StringRef Name = getString(Ops[NameIdx]);
-  DIType *Ty = transNonNullDebugType(BM->get<SPIRVExtInst>(Ops[TypeIdx]));
+  DIType *Ty = transDebugInst<DIType>(BM->get<SPIRVExtInst>(Ops[TypeIdx]));
   DIFile *File = getFile(Ops[SourceIdx]);
   SPIRVWord LineNo =
       getConstantValueOrLiteral(Ops, LineIdx, DebugInst->getExtSetKind());
@@ -1169,7 +1182,7 @@ DINode *SPIRVToLLVMDbgTran::transLocalVariable(const SPIRVExtInst *DebugInst) {
   DIFile *File = getFile(Ops[SourceIdx]);
   SPIRVWord LineNo =
       getConstantValueOrLiteral(Ops, LineIdx, DebugInst->getExtSetKind());
-  DIType *Ty = transNonNullDebugType(BM->get<SPIRVExtInst>(Ops[TypeIdx]));
+  DIType *Ty = transDebugInst<DIType>(BM->get<SPIRVExtInst>(Ops[TypeIdx]));
   DINode::DIFlags Flags = DINode::FlagZero;
   SPIRVWord SPIRVFlags =
       getConstantValueOrLiteral(Ops, FlagsIdx, DebugInst->getExtSetKind());
@@ -1203,32 +1216,24 @@ DINode *SPIRVToLLVMDbgTran::transTypedef(const SPIRVExtInst *DebugInst) {
 
 DINode *SPIRVToLLVMDbgTran::transTypeInheritance(const SPIRVExtInst *DebugInst,
                                                  DIType *ChildClass) {
-  using namespace SPIRVDebug::Operand::TypeInheritance;
-  // The value is used when assertions are enabled
-  [[maybe_unused]] unsigned OperandCount;
-  unsigned ParentIdx, OffsetIdx, FlagsIdx;
-  if (isNonSemanticDebugInfo(DebugInst->getExtSetKind())) {
-    if (!ChildClass) {
-      // Will be translated later when processing TypeMember's parent
-      return nullptr;
-    }
-    OperandCount = NonSemantic::OperandCount;
-    ParentIdx = NonSemantic::ParentIdx;
-    OffsetIdx = NonSemantic::OffsetIdx;
-    FlagsIdx = NonSemantic::FlagsIdx;
-  } else {
-    OperandCount = NonSemantic::OperandCount;
-    ParentIdx = OpenCL::ParentIdx;
-    OffsetIdx = OpenCL::OffsetIdx;
-    FlagsIdx = OpenCL::FlagsIdx;
+  if (isNonSemanticDebugInfo(DebugInst->getExtSetKind()) && !ChildClass) {
+    // Will be translated later when processing TypeMember's parent
+    return nullptr;
   }
+  using namespace SPIRVDebug::Operand::TypeInheritance;
   const SPIRVWordVec &Ops = DebugInst->getArguments();
-  assert(Ops.size() >= OperandCount && "Invalid number of operands");
+  assert(Ops.size() >= MinOperandCount && "Invalid number of operands");
+  // No Child operand for NonSemantic debug spec
+  SPIRVWord Offset = isNonSemanticDebugInfo(DebugInst->getExtSetKind()) ? 1 : 0;
   DIType *Parent =
-      transDebugInst<DIType>(BM->get<SPIRVExtInst>(Ops[ParentIdx]));
+      transDebugInst<DIType>(BM->get<SPIRVExtInst>(Ops[ParentIdx - Offset]));
+  DIType *Child =
+      isNonSemanticDebugInfo(DebugInst->getExtSetKind())
+          ? ChildClass
+          : transDebugInst<DIType>(BM->get<SPIRVExtInst>(Ops[ChildIdx]));
   DINode::DIFlags Flags = DINode::FlagZero;
-  SPIRVWord SPIRVFlags =
-      getConstantValueOrLiteral(Ops, FlagsIdx, DebugInst->getExtSetKind());
+  SPIRVWord SPIRVFlags = getConstantValueOrLiteral(Ops, FlagsIdx - Offset,
+                                                   DebugInst->getExtSetKind());
   if ((SPIRVFlags & SPIRVDebug::FlagAccess) == SPIRVDebug::FlagIsPublic)
     Flags |= llvm::DINode::FlagPublic;
   if ((SPIRVFlags & SPIRVDebug::FlagAccess) == SPIRVDebug::FlagIsProtected)
@@ -1236,14 +1241,7 @@ DINode *SPIRVToLLVMDbgTran::transTypeInheritance(const SPIRVExtInst *DebugInst,
   if ((SPIRVFlags & SPIRVDebug::FlagAccess) == SPIRVDebug::FlagIsPrivate)
     Flags |= llvm::DINode::FlagPrivate;
   uint64_t OffsetVal =
-      BM->get<SPIRVConstant>(Ops[OffsetIdx])->getZExtIntValue();
-  DIType *Child;
-  if (isNonSemanticDebugInfo(DebugInst->getExtSetKind())) {
-    Child = ChildClass;
-  } else {
-    Child =
-        transDebugInst<DIType>(BM->get<SPIRVExtInst>(Ops[OpenCL::ChildIdx]));
-  }
+      BM->get<SPIRVConstant>(Ops[OffsetIdx - Offset])->getZExtIntValue();
   return getDIBuilder(DebugInst).createInheritance(Child, Parent, OffsetVal, 0,
                                                    Flags);
 }
@@ -1414,13 +1412,6 @@ MDNode *SPIRVToLLVMDbgTran::transExpression(const SPIRVExtInst *DebugInst) {
   return getDIBuilder(DebugInst).createExpression(Addr);
 }
 
-DIType *
-SPIRVToLLVMDbgTran::transNonNullDebugType(const SPIRVExtInst *DebugInst) {
-  if (DebugInst->getExtOp() != SPIRVDebug::DebugInfoNone)
-    return transDebugInst<DIType>(DebugInst);
-  return getDIBuilder(DebugInst).createUnspecifiedType("SPIRV unknown type");
-}
-
 MDNode *SPIRVToLLVMDbgTran::transDebugInstImpl(const SPIRVExtInst *DebugInst) {
   switch (DebugInst->getExtOp()) {
   case SPIRVDebug::DebugInfoNone:
