@@ -503,27 +503,17 @@ enum {
 } // namespace TypeMember
 
 namespace TypeInheritance {
-namespace NonSemantic {
-enum {
-  ParentIdx       = 0,
-  OffsetIdx       = 1,
-  SizeIdx         = 2,
-  FlagsIdx        = 3,
-  OperandCount    = 4
-};
-}
-
-namespace OpenCL {
 enum {
   ChildIdx        = 0,
   ParentIdx       = 1,
   OffsetIdx       = 2,
   SizeIdx         = 3,
   FlagsIdx        = 4,
+  // NonSemantic
+  MinOperandCount = 4,
   OperandCount    = 5
 };
 }
-} // namespace TypeInheritance
 
 namespace TypePtrToMember {
 enum {
@@ -1001,10 +991,7 @@ inline bool hasDbgInstParentScopeIdx(
     ParentScopeIdx = TypeMember::OpenCL::ParentIdx;
     return true;
   case SPIRVDebug::TypeInheritance:
-    if (ExtKind == SPIRV::SPIRVEIS_OpenCL_DebugInfo_100)
-      ParentScopeIdx = TypeInheritance::OpenCL::ParentIdx;
-    else
-      ParentScopeIdx = TypeInheritance::NonSemantic::ParentIdx;
+    ParentScopeIdx = TypeInheritance::ParentIdx;
     return true;
   case SPIRVDebug::TypePtrToMember:
     ParentScopeIdx = TypePtrToMember::ParentIdx;
