@@ -83,10 +83,6 @@ public:
       BuiltIn BI = static_cast<BuiltIn>(Literals.back());
       return getCapability(BI);
     }
-    case DecorationUniform:
-      if (Module->isAllowedToUseVersion(VersionNumber::SPIRV_1_6))
-        return getVec(CapabilityUniformDecoration);
-      return getVec(CapabilityShader);
 
     default:
       return getCapability(Dec);
@@ -104,7 +100,6 @@ public:
     case DecorationMaxByteOffset:
       return static_cast<SPIRVWord>(VersionNumber::SPIRV_1_1);
     case DecorationUserSemantic:
-    case DecorationCounterBuffer:
       return static_cast<SPIRVWord>(VersionNumber::SPIRV_1_4);
 
     default:
@@ -156,6 +151,9 @@ public:
     case DecorationMergeINTEL:
     case DecorationBankBitsINTEL:
     case DecorationForcePow2DepthINTEL:
+    case DecorationStridesizeINTEL:
+    case DecorationWordsizeINTEL:
+    case DecorationTrueDualPortINTEL:
       return ExtensionID::SPV_INTEL_fpga_memory_attributes;
     case DecorationBurstCoalesceINTEL:
     case DecorationCacheSizeINTEL:
@@ -175,8 +173,12 @@ public:
       return ExtensionID::SPV_INTEL_float_controls2;
     case DecorationStallEnableINTEL:
       return ExtensionID::SPV_INTEL_fpga_cluster_attributes;
+    case DecorationStallFreeINTEL:
+      return ExtensionID::SPV_INTEL_fpga_cluster_attributes;
     case DecorationFuseLoopsInFunctionINTEL:
       return ExtensionID::SPV_INTEL_loop_fuse;
+    case internal::DecorationCallableFunctionINTEL:
+      return ExtensionID::SPV_INTEL_fast_composite;
     case DecorationMathOpDSPModeINTEL:
       return ExtensionID::SPV_INTEL_fpga_dsp_control;
     case DecorationInitiationIntervalINTEL:
@@ -212,8 +214,8 @@ public:
       return ExtensionID::SPV_INTEL_fpga_latency_control;
     case DecorationFPMaxErrorDecorationINTEL:
       return ExtensionID::SPV_INTEL_fp_max_error;
-    case DecorationCacheControlLoadINTEL:
-    case DecorationCacheControlStoreINTEL:
+    case internal::DecorationCacheControlLoadINTEL:
+    case internal::DecorationCacheControlStoreINTEL:
       return ExtensionID::SPV_INTEL_cache_controls;
     default:
       return {};
@@ -228,8 +230,6 @@ public:
   }
 };
 
-class SPIRVDecorateString : public SPIRVDecorate {};
-
 class SPIRVDecorateId : public SPIRVDecorateGeneric {
 public:
   static const Op OC = OpDecorateId;
@@ -345,6 +345,9 @@ public:
     case DecorationMergeINTEL:
     case DecorationBankBitsINTEL:
     case DecorationForcePow2DepthINTEL:
+    case DecorationStridesizeINTEL:
+    case DecorationWordsizeINTEL:
+    case DecorationTrueDualPortINTEL:
       return ExtensionID::SPV_INTEL_fpga_memory_attributes;
     case DecorationBurstCoalesceINTEL:
     case DecorationCacheSizeINTEL:
@@ -379,8 +382,6 @@ protected:
   SPIRVWord MemberNumber;
 };
 
-class SPIRVMemberDecorateString : public SPIRVMemberDecorate {};
-
 class SPIRVDecorationGroup : public SPIRVEntry {
 public:
   static const Op OC = OpDecorationGroup;
@@ -685,6 +686,12 @@ public:
       : SPIRVDecorate(spv::DecorationStallEnableINTEL, TheTarget) {}
 };
 
+class SPIRVDecorateStallFreeINTEL : public SPIRVDecorate {
+public:
+  SPIRVDecorateStallFreeINTEL(SPIRVEntry *TheTarget)
+      : SPIRVDecorate(spv::DecorationStallFreeINTEL, TheTarget) {}
+};
+
 class SPIRVDecorateFuseLoopsInFunctionINTEL : public SPIRVDecorate {
 public:
   // Complete constructor for SPIRVDecorateFuseLoopsInFunctionINTEL
@@ -925,31 +932,32 @@ public:
 class SPIRVDecorateCacheControlLoadINTEL : public SPIRVDecorate {
 public:
   // Complete constructor for SPIRVDecorateCacheControlLoadINTEL
-  SPIRVDecorateCacheControlLoadINTEL(SPIRVEntry *TheTarget,
-                                     SPIRVWord CacheLevel,
-                                     LoadCacheControl CacheControl)
-      : SPIRVDecorate(DecorationCacheControlLoadINTEL, TheTarget, CacheLevel,
-                      static_cast<SPIRVWord>(CacheControl)) {}
+  SPIRVDecorateCacheControlLoadINTEL(
+      SPIRVEntry *TheTarget, SPIRVWord CacheLevel,
+      spv::internal::LoadCacheControlINTEL CacheControl)
+      : SPIRVDecorate(spv::internal::DecorationCacheControlLoadINTEL, TheTarget,
+                      CacheLevel, static_cast<SPIRVWord>(CacheControl)){};
 
-  SPIRVWord getCacheLevel() const { return Literals.at(0); }
-  LoadCacheControl getCacheControl() const {
-    return static_cast<LoadCacheControl>(Literals.at(1));
-  }
+  SPIRVWord getCacheLevel() const { return Literals.at(0); };
+  spv::internal::LoadCacheControlINTEL getCacheControl() const {
+    return static_cast<spv::internal::LoadCacheControlINTEL>(Literals.at(1));
+  };
 };
 
 class SPIRVDecorateCacheControlStoreINTEL : public SPIRVDecorate {
 public:
   // Complete constructor for SPIRVDecorateCacheControlStoreINTEL
-  SPIRVDecorateCacheControlStoreINTEL(SPIRVEntry *TheTarget,
-                                      SPIRVWord CacheLevel,
-                                      StoreCacheControl CacheControl)
-      : SPIRVDecorate(DecorationCacheControlStoreINTEL, TheTarget, CacheLevel,
-                      static_cast<SPIRVWord>(CacheControl)) {}
+  SPIRVDecorateCacheControlStoreINTEL(
+      SPIRVEntry *TheTarget, SPIRVWord CacheLevel,
+      spv::internal::StoreCacheControlINTEL CacheControl)
+      : SPIRVDecorate(spv::internal::DecorationCacheControlStoreINTEL,
+                      TheTarget, CacheLevel,
+                      static_cast<SPIRVWord>(CacheControl)){};
 
-  SPIRVWord getCacheLevel() const { return Literals.at(0); }
-  StoreCacheControl getCacheControl() const {
-    return static_cast<StoreCacheControl>(Literals.at(1));
-  }
+  SPIRVWord getCacheLevel() const { return Literals.at(0); };
+  spv::internal::StoreCacheControlINTEL getCacheControl() const {
+    return static_cast<spv::internal::StoreCacheControlINTEL>(Literals.at(1));
+  };
 };
 
 } // namespace SPIRV
