@@ -171,7 +171,6 @@ inline bool isValid(spv::FunctionParameterAttribute V) {
   case FunctionParameterAttributeNoCapture:
   case FunctionParameterAttributeNoWrite:
   case FunctionParameterAttributeNoReadWrite:
-  case FunctionParameterAttributeRuntimeAlignedINTEL:
     return true;
   default:
     return false;
@@ -294,7 +293,7 @@ inline bool isValidFunctionControlMask(SPIRVWord Mask) {
   ValidMask |= FunctionControlDontInlineMask;
   ValidMask |= FunctionControlPureMask;
   ValidMask |= FunctionControlConstMask;
-  ValidMask |= FunctionControlOptNoneEXTMask;
+  ValidMask |= internal::FunctionControlOptNoneINTELMask;
 
   return (Mask & ~ValidMask) == 0;
 }
