@@ -58,18 +58,6 @@
 
 namespace SPIRV {
 
-namespace {
-std::string to_string(uint32_t Version) {
-  std::string Res(formatVersionNumber(Version));
-  Res += " (" + std::to_string(Version) + ")";
-  return Res;
-}
-
-std::string to_string(VersionNumber Version) {
-  return to_string(static_cast<uint32_t>(Version));
-}
-} // Anonymous namespace
-
 SPIRVModule::SPIRVModule()
     : AutoAddCapability(true), ValidateCapability(false), IsValid(true) {}
 
@@ -143,13 +131,6 @@ public:
   SPIRVConstant *getLiteralAsConstant(unsigned Literal) override;
   unsigned getNumFunctions() const override { return FuncVec.size(); }
   unsigned getNumVariables() const override { return VariableVec.size(); }
-  std::vector<SPIRVValue *> getFunctionPointers() const override {
-    std::vector<SPIRVValue *> Res;
-    for (auto *C : ConstVec)
-      if (C->getOpCode() == OpConstantFunctionPointerINTEL)
-        Res.emplace_back(C);
-    return Res;
-  }
   SourceLanguage getSourceLanguage(SPIRVWord *Ver = nullptr) const override {
     if (Ver)
       *Ver = SrcLangVer;
@@ -192,16 +173,7 @@ public:
   void insertEntryNoId(SPIRVEntry *Entry) override { EntryNoId.insert(Entry); }
 
   void setSPIRVVersion(SPIRVWord Ver) override {
-    if (!this->isAllowedToUseVersion(static_cast<VersionNumber>(Ver))) {
-      std::stringstream SS;
-      SS << "SPIR-V version was restricted to at most "
-         << to_string(getMaximumAllowedSPIRVVersion())
-         << " but a construct from the input requires SPIR-V version "
-         << to_string(Ver) << " or above\n";
-      getErrorLog().checkError(false, SPIRVEC_RequiresVersion, SS.str());
-      setInvalid();
-      return;
-    }
+    assert(this->isAllowedToUseVersion(static_cast<VersionNumber>(Ver)));
     SPIRVVersion = Ver;
   }
 
@@ -254,8 +226,7 @@ public:
   template <class T> T *addType(T *Ty);
   SPIRVTypeArray *addArrayType(SPIRVType *, SPIRVConstant *) override;
   SPIRVTypeBool *addBoolType() override;
-  SPIRVTypeFloat *addFloatType(unsigned BitWidth,
-                               unsigned FloatingPointEncoding) override;
+  SPIRVTypeFloat *addFloatType(unsigned BitWidth) override;
   SPIRVTypeFunction *addFunctionType(SPIRVType *,
                                      const std::vector<SPIRVType *> &) override;
   SPIRVTypeInt *addIntegerType(unsigned BitWidth) override;
@@ -276,9 +247,6 @@ public:
   addJointMatrixINTELType(SPIRVType *, std::vector<SPIRVValue *>) override;
   SPIRVTypeCooperativeMatrixKHR *
   addCooperativeMatrixKHRType(SPIRVType *, std::vector<SPIRVValue *>) override;
-  SPIRVInstruction *
-  addCooperativeMatrixLengthKHRInst(SPIRVType *, SPIRVType *,
-                                    SPIRVBasicBlock *) override;
   SPIRVType *addOpaqueGenericType(Op) override;
   SPIRVTypeDeviceEvent *addDeviceEventType() override;
   SPIRVTypeQueue *addQueueType() override;
@@ -569,8 +537,7 @@ private:
   SPIRVTypeBool *BoolTy;
   SPIRVTypeVoid *VoidTy;
   SmallDenseMap<unsigned, SPIRVTypeInt *, 4> IntTypeMap;
-  SmallDenseMap<std::pair<unsigned, unsigned>, SPIRVTypeFloat *, 4>
-      FloatTypeMap;
+  SmallDenseMap<unsigned, SPIRVTypeFloat *, 4> FloatTypeMap;
   std::map<unsigned, SPIRVConstant *> LiteralMap;
   std::vector<SPIRVExtInst *> DebugInstVec;
   std::vector<SPIRVExtInst *> AuxDataInstVec;
@@ -995,14 +962,12 @@ SPIRVTypeInt *SPIRVModuleImpl::addIntegerType(unsigned BitWidth) {
   return addType(Ty);
 }
 
-SPIRVTypeFloat *SPIRVModuleImpl::addFloatType(unsigned BitWidth,
-                                              unsigned FloatingPointEncoding) {
-  auto Desc = std::make_pair(BitWidth, FloatingPointEncoding);
-  auto Loc = FloatTypeMap.find(Desc);
+SPIRVTypeFloat *SPIRVModuleImpl::addFloatType(unsigned BitWidth) {
+  auto Loc = FloatTypeMap.find(BitWidth);
   if (Loc != FloatTypeMap.end())
     return Loc->second;
-  auto *Ty = new SPIRVTypeFloat(this, getId(), BitWidth, FloatingPointEncoding);
-  FloatTypeMap[Desc] = Ty;
+  auto *Ty = new SPIRVTypeFloat(this, getId(), BitWidth);
+  FloatTypeMap[BitWidth] = Ty;
   return addType(Ty);
 }
 
@@ -1056,14 +1021,6 @@ SPIRVModuleImpl::addCooperativeMatrixKHRType(SPIRVType *CompType,
       new SPIRVTypeCooperativeMatrixKHR(this, getId(), CompType, Args));
 }
 
-SPIRVInstruction *SPIRVModuleImpl::addCooperativeMatrixLengthKHRInst(
-    SPIRVType *RetTy, SPIRVType *MatTy, SPIRVBasicBlock *BB) {
-  return addInstruction(
-      SPIRVInstTemplateBase::create(OpCooperativeMatrixLengthKHR, RetTy,
-                                    getId(), getVec(MatTy->getId()), BB, this),
-      BB);
-}
-
 SPIRVType *SPIRVModuleImpl::addOpaqueGenericType(Op TheOpCode) {
   return addType(new SPIRVTypeOpaqueGeneric(TheOpCode, this, getId()));
 }
@@ -1178,19 +1135,17 @@ SPIRVEntry *SPIRVModuleImpl::replaceForward(SPIRVForward *Forward,
                                             SPIRVEntry *Entry) {
   SPIRVId Id = Entry->getId();
   SPIRVId ForwardId = Forward->getId();
-  if (ForwardId == Id) {
+  if (ForwardId == Id)
     IdEntryMap[Id] = Entry;
-    // Annotations include name, decorations, execution modes
-    Entry->takeAnnotations(Forward);
-  } else {
+  else {
     auto Loc = IdEntryMap.find(Id);
     assert(Loc != IdEntryMap.end());
     IdEntryMap.erase(Loc);
     Entry->setId(ForwardId);
     IdEntryMap[ForwardId] = Entry;
-    // Replace current Id with ForwardId in decorates.
-    Entry->replaceTargetIdInDecorates(ForwardId);
   }
+  // Annotations include name, decorations, execution modes
+  Entry->takeAnnotations(Forward);
   delete Forward;
   return Entry;
 }
@@ -2138,6 +2093,16 @@ void SPIRVModuleImpl::addUnknownStructField(SPIRVTypeStruct *Struct, unsigned I,
   UnknownStructFieldMap[Struct].push_back(std::make_pair(I, ID));
 }
 
+static std::string to_string(uint32_t Version) {
+  std::string Res(formatVersionNumber(Version));
+  Res += " (" + std::to_string(Version) + ")";
+  return Res;
+}
+
+static std::string to_string(VersionNumber Version) {
+  return to_string(static_cast<uint32_t>(Version));
+}
+
 std::istream &operator>>(std::istream &I, SPIRVModule &M) {
   SPIRVDecoder Decoder(I, M);
   SPIRVModuleImpl &MI = *static_cast<SPIRVModuleImpl *>(&M);
