@@ -162,15 +162,8 @@ bool SPIRVType::isTypeComposite() const {
          isTypeJointMatrixINTEL() || isTypeCooperativeMatrixKHR();
 }
 
-bool SPIRVType::isTypeFloat(unsigned Bits,
-                            unsigned FloatingPointEncoding) const {
-  if (!isType<SPIRVTypeFloat>(this))
-    return false;
-  if (Bits == 0)
-    return true;
-  const auto *ThisFloat = static_cast<const SPIRVTypeFloat *>(this);
-  return ThisFloat->getBitWidth() == Bits &&
-         ThisFloat->getFloatingPointEncoding() == FloatingPointEncoding;
+bool SPIRVType::isTypeFloat(unsigned Bits) const {
+  return isType<SPIRVTypeFloat>(this, Bits);
 }
 
 bool SPIRVType::isTypeOCLImage() const {
@@ -204,10 +197,6 @@ bool SPIRVType::isTypeSampler() const { return OpCode == OpTypeSampler; }
 
 bool SPIRVType::isTypeImage() const { return OpCode == OpTypeImage; }
 
-bool SPIRVType::isTypeSampledImage() const {
-  return OpCode == OpTypeSampledImage;
-}
-
 bool SPIRVType::isTypeStruct() const { return OpCode == OpTypeStruct; }
 
 bool SPIRVType::isTypeVector() const { return OpCode == OpTypeVector; }
