@@ -111,9 +111,7 @@ static cl::opt<VersionNumber> MaxSPIRVVersion(
                clEnumValN(VersionNumber::SPIRV_1_1, "1.1", "SPIR-V 1.1"),
                clEnumValN(VersionNumber::SPIRV_1_2, "1.2", "SPIR-V 1.2"),
                clEnumValN(VersionNumber::SPIRV_1_3, "1.3", "SPIR-V 1.3"),
-               clEnumValN(VersionNumber::SPIRV_1_4, "1.4", "SPIR-V 1.4"),
-               clEnumValN(VersionNumber::SPIRV_1_5, "1.5", "SPIR-V 1.5"),
-               clEnumValN(VersionNumber::SPIRV_1_6, "1.6", "SPIR-V 1.6")),
+               clEnumValN(VersionNumber::SPIRV_1_4, "1.4", "SPIR-V 1.4")),
     cl::init(VersionNumber::MaximumVersion));
 
 static cl::list<std::string>
@@ -146,25 +144,16 @@ static cl::opt<SPIRV::BIsRepresentation> BIsRepresentation(
                    "SPIR-V Friendly IR")),
     cl::init(SPIRV::BIsRepresentation::OpenCL12));
 
-static cl::opt<bool> PreserveOCLKernelArgTypeMetadataThroughString(
-    "preserve-ocl-kernel-arg-type-metadata-through-string", cl::init(false),
-    cl::desc("Preserve OpenCL kernel_arg_type and kernel_arg_type_qual "
-             "metadata through OpString"));
+static cl::opt<bool>
+    PreserveOCLKernelArgTypeMetadataThroughString(
+        "preserve-ocl-kernel-arg-type-metadata-through-string", cl::init(false),
+        cl::desc("Preserve OpenCL kernel_arg_type and kernel_arg_type_qual "
+                 "metadata through OpString"));
 
 static cl::opt<bool>
     SPIRVToolsDis("spirv-tools-dis", cl::init(false),
                   cl::desc("Emit textual assembly using SPIRV-Tools"));
 
-static cl::opt<bool>
-    EmitOpaquePointers("emit-opaque-pointers", cl::init(true),
-                       cl::desc("Emit opaque instead of typed LLVM pointers "
-                                "for the translation from SPIR-V."),
-                       cl::Hidden);
-
-static cl::opt<bool> SPIRVEmitFunctionPtrAddrSpace(
-    "spirv-emit-function-ptr-addr-space", cl::init(false),
-    cl::desc("Emit and consume CodeSectionINTEL for function pointers"));
-
 using SPIRV::ExtensionID;
 
 #ifdef _SPIRV_SUPPORT_TEXT_FMT
@@ -198,10 +187,9 @@ static cl::opt<bool>
     SPIRVMemToReg("spirv-mem2reg", cl::init(false),
                   cl::desc("LLVM/SPIR-V translation enable mem2reg"));
 
-static cl::opt<bool>
-    SPIRVPreserveAuxData("spirv-preserve-auxdata", cl::init(false),
-                         cl::desc("Preserve all auxiliary data, such as "
-                                  "function attributes and metadata"));
+static cl::opt<bool> SPIRVPreserveAuxData(
+    "spirv-preserve-auxdata", cl::init(false),
+    cl::desc("Preserve all auxiliary data, such as function attributes and metadata"));
 
 static cl::opt<bool> SpecConstInfo(
     "spec-const-info",
@@ -276,59 +264,6 @@ static cl::opt<SPIRV::BuiltinFormat> SPIRVBuiltinFormat(
         clEnumValN(SPIRV::BuiltinFormat::Global, "global",
                    "Use globals to represent SPIR-V builtin variables")));
 
-static cl::opt<uint32_t> FnVarCategory(
-    "fnvar-category",
-    cl::desc("Specify architecture category of the target device (omitting "
-             "this flag denotes that the target device can be of any "
-             "category). Used only with -r and --fnvar-spec-enable."),
-    cl::value_desc("category"), cl::ValueRequired);
-
-static cl::opt<uint32_t> FnVarFamily(
-    "fnvar-family",
-    cl::desc("Specify architecture family of the target device (omitting this "
-             "flag denotes that the target device can be of any family). Used "
-             "only with -r and --fnvar-spec-enable."),
-    cl::value_desc("family"), cl::ValueRequired);
-
-static cl::opt<uint32_t> FnVarArch(
-    "fnvar-arch",
-    cl::desc("Specify architecture of the target device (omitting this flag "
-             "denotes that the target device can be of any architecture). Used "
-             "only with -r and --fnvar-spec-enable."),
-    cl::value_desc("architecture"), cl::ValueRequired);
-
-static cl::opt<uint32_t>
-    FnVarTarget("fnvar-target",
-                cl::desc("Specify target of the target device (omitting this "
-                         "flag denotes that the target device can be any "
-                         "target). Used only with -r and --fnvar-spec-enable."),
-                cl::value_desc("target"), cl::ValueRequired);
-
-static cl::list<uint32_t> FnVarFeatures(
-    "fnvar-features", cl::CommaSeparated,
-    cl::desc("Specify features of the target device (omitting this flag "
-             "denotes that the target device supports all features). Used only "
-             "with -r and --fnvar-spec-enable."),
-    cl::value_desc("feature0,feature1,..."), cl::ValueRequired);
-
-static cl::list<uint32_t> FnVarCapabilities(
-    "fnvar-capabilities", cl::CommaSeparated,
-    cl::desc("Specify capabilities of the target device (omitting this flag "
-             "denotes that the target device supports all features). Used only "
-             "with -r and --fnvar-spec-enable."),
-    cl::value_desc("capability0,capability1,..."), cl::ValueRequired);
-
-static cl::opt<std::string> FnVarSpvOut(
-    "fnvar-spv-out",
-    cl::desc("Save the specialized target-specific SPIR-V module to this file. "
-             "Used only with -r and --fnvar-spec-enable."),
-    cl::value_desc("file"), cl::ValueRequired);
-
-static cl::opt<bool> FnVarSpecEnable(
-    "fnvar-spec-enable", cl::init(false),
-    cl::desc("Enable specialization of function variants according to "
-             "SPV_INTEL_function_variants. Requires -r flag."));
-
 static std::string removeExt(const std::string &FileName) {
   size_t Pos = FileName.find_last_of(".");
   if (Pos != std::string::npos)
@@ -446,7 +381,7 @@ static bool isFileEmpty(const std::string &FileName) {
 
 static int convertSPIRVToLLVM(const SPIRV::TranslatorOpts &Opts) {
   LLVMContext Context;
-
+  
   std::ifstream IFS(InputFile, std::ios::binary);
   Module *M;
   std::string Err;
@@ -801,7 +736,8 @@ int main(int Ac, char **Av) {
   }
 
   if (SPIRVPreserveAuxData) {
-    Opts.setPreserveAuxData(SPIRVPreserveAuxData);
+    Opts.setPreserveAuxData(
+        SPIRVPreserveAuxData);
     if (!IsReverse)
       Opts.setAllowedToUseExtension(
           SPIRV::ExtensionID::SPV_KHR_non_semantic_info);
@@ -841,9 +777,9 @@ int main(int Ac, char **Av) {
           SPIRV::DebugInfoEIS::NonSemantic_Shader_DebugInfo_200)
         Opts.setAllowExtraDIExpressionsEnabled(true);
       if (DebugEIS.getValue() ==
-              SPIRV::DebugInfoEIS::NonSemantic_Shader_DebugInfo_100 ||
+          SPIRV::DebugInfoEIS::NonSemantic_Shader_DebugInfo_100 ||
           DebugEIS.getValue() ==
-              SPIRV::DebugInfoEIS::NonSemantic_Shader_DebugInfo_200)
+          SPIRV::DebugInfoEIS::NonSemantic_Shader_DebugInfo_200)
         Opts.setAllowedToUseExtension(
             SPIRV::ExtensionID::SPV_KHR_non_semantic_info);
     }
@@ -852,59 +788,6 @@ int main(int Ac, char **Av) {
   if (PreserveOCLKernelArgTypeMetadataThroughString.getNumOccurrences() != 0)
     Opts.setPreserveOCLKernelArgTypeMetadataThroughString(true);
 
-  if (SPIRVEmitFunctionPtrAddrSpace.getNumOccurrences() != 0)
-    Opts.setEmitFunctionPtrAddrSpace(true);
-
-  Opts.setFnVarSpecEnable(FnVarSpecEnable);
-
-  if (!IsReverse &&
-      (FnVarSpecEnable || FnVarCategory != 0 || FnVarFamily != 0 ||
-       FnVarArch != 0 || FnVarTarget != 0 || !FnVarFeatures.empty() ||
-       !FnVarCapabilities.empty() || !FnVarSpvOut.empty())) {
-    errs() << "--fnvar-xxx flags can be used only with -r\n";
-    return -1;
-  }
-
-  if (!FnVarSpecEnable &&
-      (FnVarCategory != 0 || FnVarFamily != 0 || FnVarArch != 0 ||
-       FnVarTarget != 0 || !FnVarFeatures.empty() ||
-       !FnVarCapabilities.empty() || !FnVarSpvOut.empty())) {
-    errs() << "--fnvar-xxx flags need to be enabled with --fnvar-spec-enable\n";
-    return -1;
-  }
-
-  if (FnVarCategory.getNumOccurrences() > 0) {
-    Opts.setFnVarCategory(FnVarCategory);
-  }
-
-  if (FnVarFamily.getNumOccurrences() > 0) {
-    Opts.setFnVarFamily(FnVarFamily);
-  }
-
-  if (FnVarArch.getNumOccurrences() > 0) {
-    Opts.setFnVarArch(FnVarArch);
-  }
-
-  if (FnVarTarget.getNumOccurrences() > 0) {
-    Opts.setFnVarTarget(FnVarTarget);
-  }
-
-  if (!FnVarFeatures.empty()) {
-    Opts.setFnVarFeatures(FnVarFeatures);
-  }
-
-  if (!FnVarCapabilities.empty()) {
-    Opts.setFnVarCapabilities(FnVarCapabilities);
-  }
-
-  if (!FnVarSpvOut.empty()) {
-    Opts.setFnVarSpvOut(FnVarSpvOut);
-  }
-
-  if (!Opts.validateFnVarOpts()) {
-    return -1;
-  }
-
 #ifdef _SPIRV_SUPPORT_TEXT_FMT
   if (ToText && (ToBinary || IsReverse || IsRegularization)) {
     errs() << "Cannot use -to-text with -to-binary, -r, -s\n";
@@ -954,14 +837,15 @@ int main(int Ac, char **Av) {
     std::optional<SPIRV::SPIRVModuleReport> BinReport =
         SPIRV::getSpirvReport(IFS, ErrCode);
     if (!BinReport) {
-      std::cerr << "Invalid SPIR-V binary, error code is " << ErrCode << "\n";
+      std::cerr << "Invalid SPIR-V binary: \"" << SPIRV::getErrorMessage(ErrCode) << "\"\n";
       return -1;
     }
 
     SPIRV::SPIRVModuleTextReport TextReport =
         SPIRV::formatSpirvReport(BinReport.value());
 
-    std::cout << "SPIR-V module report:" << "\n Version: " << TextReport.Version
+    std::cout << "SPIR-V module report:"
+              << "\n Version: " << TextReport.Version
               << "\n Memory model: " << TextReport.MemoryModel
               << "\n Addressing model: " << TextReport.AddrModel << "\n";
 
@@ -978,8 +862,7 @@ int main(int Ac, char **Av) {
     std::cout << " Number of extended instruction sets: "
               << TextReport.ExtendedInstructionSets.size() << "\n";
     for (auto &ExtendedInstructionSet : TextReport.ExtendedInstructionSets)
-      std::cout << "  Extended Instruction Set: " << ExtendedInstructionSet
-                << "\n";
+      std::cout << "  Extended Instruction Set: " << ExtendedInstructionSet << "\n";
   }
   return 0;
 }
